package com.caimei.controller.order;

import com.caimei.entity.CmOperationUser;
import com.caimei.entity.WxJsonModel;
import com.caimei.service.order.OrderService;
import com.caimei.utils.JsonMapper;
import com.caimei.utils.SessionHelper;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.util.CollectionUtils;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.thymeleaf.expression.Maps;

import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 订单
 */
@Controller
@RequestMapping("/order")
public class OrderController {
    protected static final Logger logger = LoggerFactory.getLogger(OrderController.class);

    @Autowired
    private OrderService orderService;

    /**
     * 确认订单信息
     *
     * @return
     */
    @ResponseBody
    @RequestMapping("/confirm")
    public WxJsonModel confirmOrder(Integer userId, String classifyIDS, Integer organizeID, String productIDs, Integer count) {
        Map<String, Object> map = orderService.confirmOrder(userId, classifyIDS, organizeID, productIDs, count);
        return WxJsonModel.newInstance().success(map);
    }

    /**
     * 分享订单
     *
     * @return
     */
    @ResponseBody
    @RequestMapping("/share")
    public WxJsonModel shareOrder(Integer orderID) {
        String shareCode = orderService.shareOrder(orderID);
        return WxJsonModel.newInstance().success(shareCode);
    }

    /**
     * 订单详情
     */
    @ResponseBody
    @RequestMapping("/particulars")
    public WxJsonModel particulars(Integer orderID) {
        Map<String, Object> map = orderService.particulars(orderID);
        return WxJsonModel.newInstance().success(map);
    }

    /**
     * 提交订单接口
     *
     * @Param params参数格式：
     * 参数1userId用户ID
     * 参数2=organizeID组织ID，
     * 参数3=cartType购买类型（1购物车提交，2直接购买提交）
     * 参数4=ddressID订单收货地址
     * 参数5=orderInfo订单信息参数格式：
     * [
     * {"shopId":1001,
     *   "note":81,
     *  "productInfo":[{"productId":1,"productNum":80},{"productId":2,"productNum":100}]
     * }
     *]
     *参数6=balanceDeductionFlag是否使用余额抵扣(1使用，2使用)
     *参数7=orderShouldPayFee订单应付金额（商品总金额 - 余额抵扣 - 经理折扣默认为0）
     * @return code:1000=用户账户异常,1001=数据异常
     */
    @ResponseBody
    @RequestMapping("/submitOrder")
    public WxJsonModel submitOrder(String params,HttpServletRequest request) {
        WxJsonModel wxJsonModel = WxJsonModel.newInstance();
        logger.info(">>>>>>订单信息params:"+params);
        //检查用户是否登入
        CmOperationUser currentUser = SessionHelper.getCurrentUser(request);
        if(null == currentUser){
            return wxJsonModel.error("1000","用户账户异常");
        }
        Integer cmOperationID = currentUser.getId();//当前操作者ID
        if (StringUtils.isBlank(params)) {
            return wxJsonModel.error("1001","数据异常" );
        }
        Map<String, Object> map = new HashMap<String,Object>();
        try{
            map =(Map<String, Object>) JsonMapper.getInstance().fromJsonString(params, Map.class);
            if(null == map){
                logger.info(">>>>>数据异常，参数不能为空");
                return wxJsonModel.error("1001","数据异常" );
            }
            //校验传入参数的正确性
            Integer userId = (Integer) map.get("userId");
            Integer organizeID = (Integer) map.get("organizeID");
            String cartType = (String) map.get("cartType");
            Integer addressID = (Integer) map.get("addressID");
            Object orderInfo =  map.get("orderInfo");
            String balanceDeductionFlag = (String) map.get("balanceDeductionFlag");
            Double orderShouldPayFee = (Double) map.get("orderShouldPayFee");//此金额为前端计算，适用于后端计算金额复查

            if(null == userId){
                return wxJsonModel.error("1001","用户数据异常" );
            }
            if(null ==organizeID){
                return wxJsonModel.error("1001","组织数据异常" );
            }
            if(StringUtils.isEmpty(cartType)){
                return wxJsonModel.error("1001","购买类型数据异常" );
            }
            if(null ==addressID){
                return wxJsonModel.error("1001","地址数据异常" );
            }
            if(null == orderInfo){
                return wxJsonModel.error("1001","订单数据异常" );
            }
            if(StringUtils.isEmpty(balanceDeductionFlag)){
                return wxJsonModel.error("1001","余额抵扣数据异常" );
            }
            if(null == orderShouldPayFee){
                return wxJsonModel.error("1001","订单应付金额数据异常" );
            }
            //保存订单信息
            return orderService.saveOrderInfo(wxJsonModel, userId, organizeID, cartType, addressID, orderInfo, balanceDeductionFlag, orderShouldPayFee,cmOperationID);
        }catch (Exception e){
            logger.info(">>>>>系统异常"+e.getMessage());
            return wxJsonModel.error("1001","数据异常" );

        }
    }

    /**
     * 物流详情
     */
    @ResponseBody
    @RequestMapping("/")
    public WxJsonModel logistics(Integer orderID) {
        WxJsonModel model = WxJsonModel.newInstance();
        Map<String, Object> map = orderService.logistics(orderID);
        return model.success(map);
    }
}

